aboutsummaryrefslogtreecommitdiff
path: root/engines/tsage/ringworld/ringworld_scenes6.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/tsage/ringworld/ringworld_scenes6.h')
-rw-r--r--engines/tsage/ringworld/ringworld_scenes6.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/engines/tsage/ringworld/ringworld_scenes6.h b/engines/tsage/ringworld/ringworld_scenes6.h
index 976c477077..839d73ca69 100644
--- a/engines/tsage/ringworld/ringworld_scenes6.h
+++ b/engines/tsage/ringworld/ringworld_scenes6.h
@@ -30,7 +30,9 @@
#include "tsage/scenes.h"
#include "tsage/globals.h"
-namespace tSage_Ringworld {
+namespace tSage {
+
+namespace Ringworld {
using namespace tSage;
@@ -326,7 +328,8 @@ public:
}
};
+} // End of namespace Ringworld
-} // End of namespace tSage_Ringworld
+} // End of namespace tSage
#endif